<template>
    <el-dialog title="查看附件" :visible.sync="fileDialogVisible" width="800px" top="5vh" fullscreen append-to-body
      @close="handleClose">
      <filePreview v-if="lookDialogVisible" :fileUrl="currentInfo.fileMinioUrl" :currentFile="currentInfo"
        style="max-height: 90vh;overflow-y: auto;" />
    </el-dialog>
</template>

<script>
import limsTable from "@/components/Table/lims-table.vue";
import partFileList from "@/api/structural/workshop.js"
import filePreview from "@/components/Preview/filePreview.vue";
export default {
  components: {
    limsTable,
    filePreview,
  },
  props: {
    visible: {
      type: Boolean,
      default: false
    },
    partNo: {
      type: String,
      default: ''
    }
  },
  computed: {},
  data() {
    return {
      columnFile: [
        {
          dataType: 'tag',
          label: '类型',
          prop: 'type',
          formatData: (params) => {
            if (params == 1) {
              return '图片'
            } else if (params == 2) {
              return '文件'
            } else {
              return ''
            }
          },
          formatType: (params) => {
            if (params == 1) {
              return 'success'
            } else if (params == 2) {
              return 'warning'
            } else {
              return ''
            }
          }
        },
        { label: '附件名称', prop: 'fileName' },
        { label: '上传人', prop: 'name' },
        { label: '上传时间', prop: 'createTime' },
        {
          dataType: 'action',
          fixed: 'right',
          label: '操作',
          width: '170px',
          operation: [
            {
              name: '下载',
              type: 'text',
              clickFun: (row) => {
                this.handleDown(row);
              }
            },
            {
              name: '预览',
              type: 'text',
              clickFun: (row) => {
                console.log('预览文件信息:', row)
                this.currentInfo = row
                this.lookDialogVisible = true
              }
            },
          ]
        }
      ],
      tableDataFile: [],
      tableLoadingFile: false,
      lookDialogVisible: false,
      currentInfo: {},
      fileDialogVisible: false,
    }
  },
  mounted() {
    this.getFileList()
  },
  methods: {
    // 查询附件查看列表回调
    getFileList() {
      this.tableLoadingFile = true
      partFileList({ partNo: this.partNo }).then(res => {
        this.tableLoadingFile = false
        if (res.code === 200) {
          this.tableDataFile = res.data
          console.log('文件列表数据:', this.tableDataFile)
        }
      }).catch(err => {
        this.tableLoadingFile = false
      })
    },

    // 下载附件的文件
    handleDown(row) {
      this.$download.saveAs(row.fileUrl, row.fileName);
    },
  }
}
</script>

<style scoped></style>